﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections;
using Infragistics.DragDrop;
using System.Collections.ObjectModel;
using Infragistics.Controls.Grids;
using Infragistics.Controls.Grids.Primitives;
using Infragistics.Windows;

namespace DragDropRowsBetweenWindows
{
    /// <summary>
    /// Interaction logic for DraggableGridView.xaml
    /// </summary>
    public partial class DraggableGridView : UserControl
    {
        public DraggableGridView()
        {
            InitializeComponent();
        }

        private void XamGrid_CellControlAttached(object sender, Infragistics.Controls.Grids.CellControlAttachedEventArgs e)
        {
            DragSource ds = new DragSource { IsDraggable = true };
            ds.DragStart += (ss, ee) =>
                {
                    ((ee.DragSource as CellsPanel).Row as Row).CellStyle = Resources["DragStyle"] as Style;                 
                };
            ds.DragEnter += (ss, ee) =>
                {
                    if(ee.DropTarget is CellsPanel)
                        ((ee.DropTarget as CellsPanel).Row as Row).CellStyle = Resources["DragOver"] as Style;
                    if (ee.DropTarget is XamGrid)
                        (ee.DropTarget as XamGrid).Background = Brushes.Green;
                };
            ds.DragLeave += (ss, ee) =>
                {
                    if(ee.DropTarget is CellsPanel)
                        ((ee.DropTarget as CellsPanel).Row as Row).CellStyle = new Style(typeof(CellControl));
                    if (ee.DropTarget is XamGrid)
                        (ee.DropTarget as XamGrid).Background = Brushes.Transparent;
                };
            ds.DragEnd += (ss, ee) =>
                {
                    ((ee.DragSource as CellsPanel).Row as Row).CellStyle = new Style(typeof(CellControl));
                };

            ds.Drop += new EventHandler<DropEventArgs>(ds_Drop);

            DragDropManager.SetDragSource(e.Cell.Row.Control, ds);
            DragDropManager.SetDropTarget(e.Cell.Row.Control, new DropTarget { IsDropTarget = true});
        }

        void ds_Drop(object sender, DropEventArgs e)
        {
            if (e.DropTarget is XamGrid)
            {
                (e.DropTarget as XamGrid).Background = Brushes.Transparent;
                ChartData dragData = (e.DragSource as CellsPanel).Row.Data as ChartData;
                ObservableCollection<ChartData> source = (e.DropTarget as XamGrid).ItemsSource as ObservableCollection<ChartData>;

                source.Add(dragData);
            }

            if (e.DropTarget is CellsPanel)
            {
                ((e.DropTarget as CellsPanel).Row as Row).CellStyle = new Style(typeof(CellControl));

                ChartData dragData = (e.DragSource as CellsPanel).Row.Data as ChartData;
                ChartData dropData = (e.DropTarget as CellsPanel).Row.Data as ChartData;
                ObservableCollection<ChartData> source = (Utilities.GetAncestorFromType(e.DropTarget, typeof(XamGrid), false) as XamGrid).ItemsSource as ObservableCollection<ChartData>;

                source.Insert(source.IndexOf(dropData), dragData);

            }
        }

        public IEnumerable ItemsSource
        {
            get { return (IEnumerable)GetValue(ItemsSourceProperty); }
            set { SetValue(ItemsSourceProperty, value); }
        }

        // Using a DependencyProperty as the backing store for ItemsSource.  This enables animation, styling, binding, etc...
        public static readonly DependencyProperty ItemsSourceProperty =
            DependencyProperty.Register("ItemsSource", typeof(IEnumerable), typeof(DraggableGridView), new UIPropertyMetadata(null));



    }
}
